package de.rcr1.brain;

import java.util.Vector;

/**
 * A map of the mars, layed out as a grid of bytes.
 * 
 * @author Kilian Koller
 */
class Board
{
    /** The grid. */
    byte[][] grid;
    
    /**
     * Standard ctor.
     */
    Board()
    {
        grid = new byte[Constants.MARS_HEIGHT][Constants.MARS_WIDTH];
        
        // Fill mars with unknown fields
        for(int v = 0; v < grid.length; v++)
        {
            for(int h = 0; h < grid[v].length; h++)
            {
                grid[v][h] = Constants.FIELD_UNKNOWN;
            }
        }
    }
    
    /**
     * Ctor for testing.
     * 
     * @param g a byte array with the correct size.
     */
    Board(byte[][] g)
    {
        grid = g;
    }
    
    /**
     * All the reachable nodes from the center node.
     * 
     * @param center the node to calculate the others from.
     * @return all reachable nodes from center.
     */
    Vector<Node> getSurroundingPositions(Node center)
    {       
        Vector<Node> surroundingPositions = new Vector<Node>();
        
        // Left.
        if(center.getPosH() > 0 &&
                grid[center.getPosV()][center.getPosH() - 1] != Constants.FIELD_BLOCKED)
            surroundingPositions.add(new Node(center.getPosH() - 1, center.getPosV(), center, center.getG() + 1));
        
        // Right.
        if(center.getPosH() < Constants.MARS_WIDTH - 1 &&
                grid[center.getPosV()][center.getPosH() + 1] != Constants.FIELD_BLOCKED)
            surroundingPositions.add(new Node(center.getPosH() + 1, center.getPosV(), center, center.getG() + 1));
        
        // Above.
        if(center.getPosV() > 0 &&
                grid[center.getPosV() - 1][center.getPosH()] != Constants.FIELD_BLOCKED)
            surroundingPositions.add(new Node(center.getPosH(), center.getPosV() - 1, center, center.getG() + 1));
        
        // Below.
        if(center.getPosV() < Constants.MARS_HEIGHT - 1 &&
                grid[center.getPosV() + 1][center.getPosH()] != Constants.FIELD_BLOCKED)
            surroundingPositions.add(new Node(center.getPosH(), center.getPosV() + 1, center, center.getG() + 1));
        
        return surroundingPositions;
    }
    
    /**
     * Returns a field of the board.
     * 
     * @param n the position of the field.
     * @return the byte in position n.
     */
    byte getPosition(Node n)
    {
        return grid[n.getPosV()][n.getPosH()];
    }
    
    /**
     * Marks a position blocked.
     * 
     * @param n the node which is blocked.
     */
    void setBlocked(Node n)
    {
        grid[n.getPosV()][n.getPosH()] = Constants.FIELD_BLOCKED;
    }
    
    /**
     * Prints the board.
     */
    void print()
    {
        for(int v = 0; v < grid.length; v++)
        {
            for(int h = 0; h < grid[v].length; h++)
            {
                System.out.print(grid[v][h]);
            }
            System.out.println();
        }
    }
}
