package de.rcr1.brain;

import java.io.*;
import java.net.*;

/**
 * Implements the communication between Brain and Proxy.
 * 
 * @author Daniel Eitler
 *
 */
public class RemoteRobot implements Robot
{
	 Socket tell;
	 
	 /** Outputstream for writing to the Proxy. */
	 DataOutputStream output;
	 
	 /** Outputstream for reading from the Proxy. */
	 DataInputStream input;
	 
	 /**
      * Default Ctor.
      * 
      * @param host the proxy to connect to.
      * @param port the network port to connect to.
      */
	public RemoteRobot(String host,int port)
	{
		initRobot(host, port);
	}
	
	/**
      * Initializes the communication between Brain and Proxy.
      * 
      * @param host the proxy to connect to.
      * @param port the network port to connect to.
      */
	public void initRobot(String host, int port)
	{
	    try
	    {
	        tell = new Socket(host,port);
	        output = new DataOutputStream(tell.getOutputStream());
	        input = new DataInputStream(tell.getInputStream());
	        
	        System.out.println("Connection to the proxy is established");
	    }
	    catch(Exception e)
	    {
	        System.out.println(e.toString());
	    }	
	}
	
	/**
      * Sends a Packet to the Proxy an receives an answer from the Proxy.
      *  
      * @param p Packet that should be send to the Proxy.
      * @return Packet from the Proxy, representing the answer from the RCX.
      */
	 public Packet sendCommand(Packet p)
	 {    	 
	    try
	    {
	    	output.writeInt(p.getCommand());
	    	output.writeInt(p.getValue());
	    	
	    	output.flush();

	    	int resultCode = input.readInt();
	    	int resultData = input.readInt();
	    	
	    	// Packet from rcx
            System.out.println("Received: " + resultCode + "/" + resultData);
	    	
            return new Packet(resultCode, resultData);
	    }
	    catch(Exception e)
	    {
	    	System.out.println(e.toString());
	    }
	    return null;
	 }
}