/**
 * Munich University of Applied Sciences, FB07 Computer Science
 * FWP - Remotely Controlled Robot - 7.Semester
 * 
 * Class Description:
 * 		This class describes the protocol (opcodes) used via the IR connection
 * 		between the RCX and it's IR-proxy-counterpart
 * 
 * @author Thomas Woellert (thomas.woellert@t-online.de)
 * @author Stefan Weissbach (weissbst@gmx.de)
 * @author Willi Tremmel (TremmelW@gmx.de)
 * 
 * System: Linux 2.6, Sun Java JDK 5.0
 * Semestergroup: 7T
 */
package util;

public class IRProtocol {

	/**
	 * Private Constructor
	 * If there is no default constructor the compiler will create a public one
	 */
	private IRProtocol() {}
	
	/**
	 * Opcodes which can be received by the RCX
	 * Proxy->RCX
	 */
	
	
	/**
	 * ###
	 * Range : 0 - 99
	 * 100 - Forward
	 * 200 - Backward
	 * 300 - Right
	 * 400 - Left
	 * 500 - Success
	 * 600 - Error
	 * 700 - Alive
	 * 800 - Ack
	 */
	
	/* Opcode - Move Forward - need to be followed by the distance to move */
	public static final int OPCODE_FORWARD = 1000;
	
	/* Opcode - Move Backward - need to be followed by the distance to move */
	public static final int OPCODE_BACKWARD = 2000;
	
	/* Opcode - Move Right - need to be followed by the distance to move */
	public static final int OPCODE_RIGHT = 3000;
	
	/* Opcode - Move Left - need to be followed by the distance to move */
	public static final int OPCODE_LEFT = 4000;
	
	/**
	 * Opcode which are transmitted by the RCX
	 * RCX->Proxy
	 */
	
	/* Opcode - Movement successfully completed - followed by the moved distance */
	public static final int OPCODE_MOVE_SUCCESS = 5000;
	
	/* Opcode - Movement not successfull - followed by the moved distance */
	public static final int OPCODE_MOVE_ERROR = 6000;

	/**
	 * Opcodes which can be received and transmitted by the RCX and the proxy
	 * RCX<->Proxy
	 */
	
	/* Opcode - Are we active? - Does not contain any additional bytes */
	public static final int OPCODE_ACTIVE = 7000;
	
	/**
	 * Internal Opcodes for handshaking
	 */
	
	/* Handshaking, telling the other side that to acknowledge the last message */
	public static final int OPCODE_MESSAGE_ACK = 8000;	
}
